@@ -29,8 +29,8 @@ setLocalTranslate('cl_lib3', sys.modules[__name__])
 class xml_xfcepanel(xml_xfce):
     """Класс для объединения xfce-panel файлов"""
 
-    def __init__(self, text):
-        xml_xfce.__init__(self, text)
+    def prepare(self):
+        super(xml_xfcepanel, self).prepare()
         self.panelNumbers = {}
 
     def textToXML(self):
