@@ -465,6 +465,16 @@ class typeFile(object):
         """Закрываем magic"""
         self.magicObject.close()
 
+    def getMTypeBuf(self, buf):
+        try:
+            ret = self.magicObject.buffer(buf)
+        except UnicodeDecodeError:
+            try:
+                ret = self.magicObject.buffer(buf.decode('utf-8'))
+            except UnicodeDecodeError:
+                return None
+        return ret
+
     def getMType(self, filename):
         """Информация о типе файла"""
         try:
